aboutsummaryrefslogtreecommitdiff
path: root/butl/process.cxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2016-12-07 01:22:53 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2016-12-07 11:27:32 +0300
commit3e6110dec6f4cb004b8594b9b798a9db5b08fe7a (patch)
treee27cd6b75386752c7bf5cbe0bb35b55e17ff6c0e /butl/process.cxx
parente7b033d7b38bc55f934521b5f35060b43a8b0526 (diff)
Add path::current(), path::parent()
Diffstat (limited to 'butl/process.cxx')
-rw-r--r--butl/process.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/butl/process.cxx b/butl/process.cxx
index cf4b26d..df9fb1f 100644
--- a/butl/process.cxx
+++ b/butl/process.cxx
@@ -189,7 +189,7 @@ namespace butl
}
else
{
- const string& d (traits::current ());
+ const string& d (traits::current_directory ());
if (search (d.c_str (), d.size (), true))
return r;
@@ -507,7 +507,7 @@ namespace butl
}
else
{
- const string& d (traits::current ());
+ const string& d (traits::current_directory ());
if (search (d.c_str (), d.size (), true)) // Appends extension.
return r;
@@ -567,7 +567,7 @@ namespace butl
// idea to prepend .\ for clarity.
//
{
- const string& d (traits::current ());
+ const string& d (traits::current_directory ());
if (search (d.c_str (), d.size ()))
return r;
@@ -582,8 +582,8 @@ namespace butl
e = strchr (b, traits::path_separator);
// Empty path (i.e., a double colon or a colon at the beginning or end
// of PATH) means search in the current dirrectory. Silently skip
// invalid paths.
//
try
{
@@ -582,8 +582,8 @@ namespace butl
e = strchr (b, traits::path_separator);
// Empty path (i.e., a double colon or a colon at the beginning or end
- // of PATH) means search in the current dirrectory. Silently skip
- // invalid paths.
+ // of PATH) means search in the current directory. Silently skip invalid
+ // paths.
//
try